@@ -1,5 +1,4 @@
-/* $Id: cdb_make.c,v 1.12 2006/06/28 17:49:21 mjt Exp $
- * basic cdb creation routines
+/* cdb_make.c: basic cdb creation routines
  *
  * This file is a part of tinycdb package by Michael Tokarev, mjt@corpit.ru.
  * Public domain.
@@ -34,10 +33,12 @@ _cdb_make_fullwrite(int fd, const unsigned char *buf, unsigned len)
 {
   while(len) {
     int l = write(fd, buf, len);
-    if (l < 0 && errno != EINTR)
+    if (l > 0) {
+      len -= l;
+      buf += l;
+    }
+    else if (l < 0 && errno != EINTR)
       return -1;
-    len -= l;
-    buf += l;
   }
   return 0;
 }
